@@ -232,8 +232,7 @@ class BokehBackend(Plot):
         A dictionary of keywords/values which is passed to Plotly's scatter
         functions to customize the appearance. Default to:
         ``line_kw = dict(line_width = 2)``
-        Refer to this documentation page:
-        https://docs.bokeh.org/en/latest/docs/reference/plotting.html?highlight=line#bokeh.plotting.Figure.line
+        Refer to [#fn1]_ to learn more about customization.
 
     quiver_kw : dict, optional
         A dictionary with keyword arguments to customize the quivers.
@@ -254,20 +253,19 @@ class BokehBackend(Plot):
 
     theme : str, optional
         Set the theme. Default to ``"dark_minimal"``. Find more Bokeh themes
-        at the following page:
-        https://docs.bokeh.org/en/latest/docs/reference/themes.html
+        at [#fn2]_ .
+        
+
+    References
+    ==========
+    .. [#fn1] https://docs.bokeh.org/en/latest/docs/reference/plotting.html?highlight=line#bokeh.plotting.Figure.line
+    .. [#fn2] https://docs.bokeh.org/en/latest/docs/reference/themes.html
 
 
-    Notes
-    =====
-
-    In order to export the plots, the user also need to install the packages
-    listed in the following page:
-    https://docs.bokeh.org/en/latest/docs/user_guide/export.html
-
-    At the time of writing this backend, geckodriver is not available to pip.
-    Do a quick search on the web to find the appropriate installer.
+    See also
+    ========
 
+    Plot, MatplotlibBackend, PlotlyBackend, K3DBackend
     """
 
     _library = "bokeh"
@@ -303,14 +301,17 @@ class BokehBackend(Plot):
         self._init_cyclers()
 
         TOOLTIPS = [("x", "$x"), ("y", "$y")]
+        if len(self.series) > 0:
+            # empty plots (with len(series)==0) should only have x, y tooltips
 
-        if all([s.is_parametric for s in self.series]):
-            # with parametric plots, also visualize the parameter
-            TOOLTIPS += [("u", "@us")]
-        if any([s.is_complex and s.is_domain_coloring for s in self.series]):
-            # with complex domain coloring, shows the magnitude and phase
-            # in the tooltip
-            TOOLTIPS += [("Abs", "@abs"), ("Arg", "@arg")]
+            if all([s.is_parametric for s in self.series]):
+                # with parametric plots, also visualize the parameter
+                TOOLTIPS += [("u", "@us")]
+            if any([s.is_complex and s.is_domain_coloring for s
+                    in self.series]):
+                # with complex domain coloring, shows the magnitude and phase
+                # in the tooltip
+                TOOLTIPS += [("Abs", "@abs"), ("Arg", "@arg")]
 
         sizing_mode = cfg["bokeh"]["sizing_mode"]
         if any(s.is_complex and s.is_domain_coloring for s in self.series):
@@ -452,8 +453,7 @@ class BokehBackend(Plot):
                         )
 
             elif s.is_2Dvector:
-                streamlines = self._kwargs.get("streamlines", False)
-                if streamlines:
+                if s.is_streamlines:
                     x, y, u, v = s.get_data()
                     sqk = dict(color=next(self._cl), line_width=2, line_alpha=0.8)
                     stream_kw = self._kwargs.get("stream_kw", dict())
@@ -527,9 +527,9 @@ class BokehBackend(Plot):
                 if colors is not None:
                     # chroma/phase-colorbar
                     cm1 = LinearColorMapper(
-                        palette=[tuple(c) for c in colors], low=-self.pi, high=self.pi
+                        palette=[tuple(c) for c in colors], low=-np.pi, high=np.pi
                     )
-                    ticks = [-self.pi, -self.pi / 2, 0, self.pi / 2, self.pi]
+                    ticks = [-np.pi, -np.pi / 2, 0, np.pi / 2, np.pi]
                     labels = ["-π", "-π / 2", "0", "π / 2", "π"]
                     colorbar1 = ColorBar(
                         color_mapper=cm1,
@@ -671,8 +671,7 @@ class BokehBackend(Plot):
 
                 elif s.is_2Dvector:
                     x, y, u, v = s.get_data()
-                    streamlines = self._kwargs.get("streamlines", False)
-                    if streamlines:
+                    if s.is_streamlines:
                         sqk = dict(color=next(self._cl), line_width=2, line_alpha=0.8)
                         stream_kw = self._kwargs.get("stream_kw", dict())
                         density = stream_kw.pop("density", 2)
@@ -714,17 +713,36 @@ class BokehBackend(Plot):
                     rend[i].data_source.data.update(source)
 
     def save(self, path, **kwargs):
+        """ Export the plot to a static picture or to an interactive html file.
+
+        Refer to [#fn3]_ and [#fn4]_ to visualize all the available keyword
+        arguments.
+
+        Notes
+        =====
+        
+        1. In order to export static pictures, the user also need to install the
+           packages listed in [#fn5]_.
+        2. When exporting a fully portable html file, by default the necessary
+           Javascript libraries will be loaded with a CDN. This creates the
+           smallest file size possible, but it requires an internet connection
+           in order to view/load the file and its dependencies.
+
+        References
+        ==========
+        .. [#fn3] https://docs.bokeh.org/en/latest/docs/user_guide/export.html
+        .. [#fn4] https://docs.bokeh.org/en/latest/docs/user_guide/embed.html
+        .. [#fn5] https://docs.bokeh.org/en/latest/docs/reference/io.html#module-bokeh.io.export
+
+        """
         # TODO: an error get raised if I uncomment the following line
         # self._process_series(self._series)
         ext = os.path.splitext(path)[1]
-
-        # TODO:
-        # https://docs.bokeh.org/en/latest/docs/user_guide/embed.html
-        
-        if (ext == ".html") or (ext == ".htm"):
+        if ext.lower() in [".html", ".html"]:
             from bokeh.resources import CDN
             from bokeh.embed import file_html
-            html = file_html(self.fig, CDN, "bokeh_plot")
+            skw = dict(resources=CDN, title="Bokeh Plot")
+            html = file_html(self.fig, **merge(skw, kwargs))
             with open(path, 'w') as f:
                 f.write(html)
         elif ext == ".svg":
@@ -744,6 +762,7 @@ class BokehBackend(Plot):
         doc.add_root(self._fig)
 
     def show(self):
+        """Visualize the plot on the screen."""
         self._process_series(self._series)
         if self._run_in_notebook:
             # TODO: the current way we are launching the server only works within
