@@ -41,12 +41,16 @@ class DynamicParam(param.Parameterized):
 
     def _tuple_to_dict(self, k, v):
         """The user can provide a variable length tuple/list containing:
-            (default, softbounds, N, label, spacing)
+
+        (default, min, max, N [optional], label [optional], spacing [optional])
+
         where:
             default : float
                 Default value of the slider
-            softbounds : tuple
-                Tuple of two float (or integer) numbers: (start, end).
+            min : float
+                Minimum value of the slider.
+            max : float
+                Maximum value of the slider.
             N : int
                 Number of increments in the slider.
                 (start - end) / N represents the step increment. Default to 40.
@@ -63,7 +67,8 @@ class DynamicParam(param.Parameterized):
         defaults_keys = ["default", "softbounds", "step", "label", "type"]
         defaults_values = [
             1,
-            (0, 2),
+            0,
+            2,
             N,
             "$%s$" % latex(k) if self.use_latex else str(k),
             "linear",
@@ -71,12 +76,12 @@ class DynamicParam(param.Parameterized):
         values = defaults_values.copy()
         values[: len(v)] = v
         # set the step increment for the slider
-        _min, _max = values[1][0], values[1][1]
-        if values[2] > 0:
-            N = values[2]
-            values[2] = (_max - _min) / N
+        _min, _max = values[1], values[2]
+        if values[3] > 0:
+            N = values[3]
+            values[3] = (_max - _min) / N
         else:
-            values[2] = 1
+            values[3] = 1
 
         if values[-1] == "log":
             # In case of a logarithm slider, we need to instantiate the custom
@@ -89,8 +94,14 @@ class DynamicParam(param.Parameterized):
             default = values[0]
             if default not in options:
                 default = min(options, key=lambda x: abs(x - default))
-            return MyList(default=default, objects=list(options), label=values[3])
+            return MyList(default=default, objects=list(options), label=values[4])
 
+        # combine _min, _max into softbounds tuple
+        values = [
+            values[0],
+            (values[1], values[2]),
+            *values[3:]
+        ]
         return {k: v for k, v in zip(defaults_keys, values)}
 
     def __init__(self, *args, name="", params=None, **kwargs):
@@ -146,7 +157,7 @@ class PanelLayout:
     the library panel.
     """
 
-    def __init__(self, layout, ncols):
+    def __init__(self, layout, ncols, throttled=False):
         """
         Parameters
         ==========
@@ -160,6 +171,11 @@ class PanelLayout:
 
             ncols : int
                 Number of columns to lay out the widgets. Default to 2.
+
+            throttled : boolean, optional
+                Default to False. If True the recompute will be done at
+                mouse-up event on sliders. If False, every slider tick will
+                force a recompute.
         """
         # NOTE: More often than not, the numerical evaluation is going to be
         # resource-intensive. By default, panel's sliders will force a recompute
@@ -168,12 +184,6 @@ class PanelLayout:
         # event, which is set using throttled=True.
         #
         # https://panel.holoviz.org/reference/panes/Param.html#disabling-continuous-updates-for-slider-widgets
-        #
-        # The procedure is not optimal, as we need to re-map again the
-        # parameters with the widgets: for param.Number, param.Integer there is
-        # no one-on-one mapping. For example, a bounded param.Integer
-        # will create an IntegerSlider, whereas an unbounded param.Integer will
-        # create a IntInput.
 
         layouts = ["tb", "bb", "sbl", "sbr"]
         layout = layout.lower()
@@ -185,27 +195,23 @@ class PanelLayout:
             layout = "tb"
         self._layout = layout
 
-        widgets = {}
+        # NOTE: here I create a temporary panel.Param object in order to reuse
+        # the code from the pn.Param.widget method, which returns the correct
+        # widget associated to a given parameter's type.
+        # Alternatively, I would need to copy parts of that method in order to
+        # deal with the different representations of param.Integer and
+        # param.Number depending if the bounds are None values.
+        # Note that I'm only interested in the widget type: panel is then going
+        # to recreate the widgets and setting the proper throttled value. This
+        # is definitely not an optimal procedure, as we are creating the "same"
+        # widget two times, but it works :)
+        tmp_panel = pn.Param(self)
+        widgets = dict()
         for k, v in self.mapping.items():
+            widgets[v] = { "type": type(tmp_panel.widget(v)) }
             t = getattr(self.param, v)
-            widget = ""
-            if isinstance(t, param.Integer):
-                widget = pn.widgets.IntSlider
-                if t.bounds and any([(b is None) for b in t.bounds]):
-                    widget = pn.widgets.IntInput
-            elif isinstance(t, param.Number):
-                widget = pn.widgets.FloatSlider
-                if t.bounds and any([(b is None) for b in t.bounds]):
-                    widget = pn.widgets.FloatInput
-            elif isinstance(t, MyList):
-                # TODO: it seems like DiscreteSlider doesn't support throttling
-                widget = pn.widgets.DiscreteSlider
-
             if isinstance(t, param.Number):
-                widgets[v] = {
-                    "type": widget,
-                    "throttled": True,
-                }
+                widgets[v]["throttled"] = throttled
 
         self.controls = pn.Param(
             self,
@@ -259,7 +265,7 @@ class InteractivePlot(DynamicParam, PanelLayout):
     def __new__(cls, *args, **kwargs):
         return object.__new__(cls)
 
-    def __init__(self, *args, name="", params=None, aux=dict(), **kwargs):
+    def __init__(self, *args, name="", params=None, **kwargs):
         """
         Parameters
         ==========
@@ -270,20 +276,18 @@ class InteractivePlot(DynamicParam, PanelLayout):
             params : dict
                 In the keys there will be the symbols, in the values there will
                 be parameters to create the slider associated to a symbol.
-            aux : dict
-                Auxiliary dictionary containing keyword arguments to be passed
-                to DynamicParam.
             kwargs : dict
                 Usual keyword arguments to be used by the backends and series.
         """
+
         layout = kwargs.pop("layout", "tb")
         ncols = kwargs.pop("ncols", 2)
-
-        aux.setdefault("use_latex", kwargs.pop("use_latex", True))
+        throttled = kwargs.pop("throttled", False)
+        use_latex = kwargs.pop("use_latex", True)
 
         args = list(map(_plot_sympify, args))
-        super().__init__(*args, name=name, params=params, **aux)
-        PanelLayout.__init__(self, layout, ncols)
+        super().__init__(*args, name=name, params=params, use_latex=use_latex)
+        PanelLayout.__init__(self, layout, ncols, throttled)
 
         # create the series
         series = self._create_series(*args, **kwargs)
@@ -345,8 +349,15 @@ class InteractivePlot(DynamicParam, PanelLayout):
 def iplot(*args, show=True, **kwargs):
     """
     Create interactive plots of symbolic expressions.
+
+    Notes
+    =====
     
-    NOTE: this function currently only works within Jupyter Notebook!
+    This function is specifically designed to work within Jupyter Notebook!
+    It is also possible to use it from a regular Python interpreter, but only
+    with ``BokehBackend`` and ``PlotlyBackend``. In such cases, we have to
+    call ``iplot(..., backend=BB).show()``, which will create a server process
+    loading the interactive plot on the browser.
 
     Parameters
     ==========
@@ -364,18 +375,16 @@ def iplot(*args, show=True, **kwargs):
         specified. The ranges will create the discretized domain.
 
     params : dict
-        A dictionary mapping the parameter-symbols to a parameter.
-        The parameter can be:
+        A dictionary mapping the symbols to a parameter. The parameter can be:
 
-        1. an instance of ``param.parameterized.Parameter`` (at the moment,
-           ``param.Number`` is supported, which will result in a slider).
+        1. an instance of ``param.parameterized.Parameter``.
         2. a tuple of the form:
-           ``(default, (min, max), N [optional], label [optional], spacing [optional])``
+           ``(default, min, max, N [optional], label [optional], spacing [optional])``
            where:
 
            - N : int
                 Number of steps of the slider.
-           - (min, max) : (float, float)
+           - min, max : float
                 End values of the range. Must be finite numbers.
            - label: str
                 Custom text associated to the slider.
@@ -400,9 +409,10 @@ def iplot(*args, show=True, **kwargs):
         - ``'bb'``: controls in the bottom bar.
         - ``'sbl'``: controls in the left side bar.
         - ``'sbr'``: controls in the right side bar.
-        
-        Default layout to ``'tb'``. Keep in mind that side bar layouts may not
-        work well with some backends.
+
+        Default layout to ``'tb'``. Note that side bar layouts may not
+        work well with some backends, and with ``MatplotlibBackend`` the widgets
+        are always going to be displayed below the figure.
 
     ncols : int, optional
         Number of columns to lay out the widgets. Default to 2.
@@ -447,7 +457,7 @@ def iplot(*args, show=True, **kwargs):
     n : int, optional
         Set the number of discretization points on all directions.
         It overrides ``n1, n2, n3``.
-    
+
     nc : int, optional
         Number of discretization points for the contour plot when
         ``is_complex=True``.
@@ -456,6 +466,10 @@ def iplot(*args, show=True, **kwargs):
         Default to False. If True, generate a polar plot of a curve with radius
         `expr` as a function of the range
 
+    throttled : boolean, optional
+        Default to False. If True the recompute will be done at mouse-up event
+        on sliders. If False, every slider tick will force a recompute.
+
     title : str, optional
         Title of the plot. It is set to the latex representation of
         the expression, if the plot has only one expression.
@@ -494,7 +508,7 @@ def iplot(*args, show=True, **kwargs):
     0 to 1, with a default value of 0.15, discretized with 100 points on both
     directions. Note the use of ``threed=True`` to specify a 3D plot. If
     ``threed=False``, a contour plot will be generated.
-    
+
     .. jupyter-execute::
 
         >>> r = sqrt(x**2 + y**2)
@@ -502,7 +516,7 @@ def iplot(*args, show=True, **kwargs):
         >>> expr = 10 * cos(r) * exp(-r * d)
         >>> iplot(
         ...     (expr, (x, -10, 10), (y, -10, 10)),
-        ...     params = { d: (0.15, (0, 1)) },
+        ...     params = { d: (0.15, 0, 1) },
         ...     title = "My Title",
         ...     xlabel = "x axis",
         ...     ylabel = "y axis",
@@ -526,9 +540,9 @@ def iplot(*args, show=True, **kwargs):
         ...     (exp(-(x - 2)) + A2 * cos(x), (x, 0, 20), "f2"),
         ...     (A1 + A1 * cos(x), A2 * sin(x), (x, 0, pi)),
         ...     params = {
-        ...         k: (1, (0, 5)),
-        ...         A1: (2, (0, 10), 20, "Ampl 1"),
-        ...         A2: (2, (0, 10), 40, "Ampl 2"),
+        ...         k: (1, 0, 5),
+        ...         A1: (2, 0, 10, 20, "Ampl 1"),
+        ...         A2: (2, 0, 10, 40, "Ampl 2"),
         ...     },
         ...     backend = MB,
         ...     ylim=(-4, 10))
@@ -542,8 +556,8 @@ def iplot(*args, show=True, **kwargs):
         >>> iplot(
         ...     (Matrix([z * a, y * b, x]), (x, -5, 5), (y, -5, 5), (z, -5, 5)),
         ...     params = {
-        ...         a: (1, (0, 5)),
-        ...         b: (1, (0, 5))
+        ...         a: (1, 0, 5),
+        ...         b: (1, 0, 5)
         ...     },
         ...     backend = MB,
         ...     n = 10,
@@ -559,7 +573,7 @@ def iplot(*args, show=True, **kwargs):
         >>> iplot(
         ...     ((z**2 + 1) / (x * (z**2 - 1)), (z, -4 - 2 * I, 4 + 2 * I)),
         ...     params = {
-        ...         x: (1, (-2, 2))
+        ...         x: (1, -2, 2)
         ...     },
         ...     backend = MB,
         ...     is_complex = True,
@@ -576,9 +590,9 @@ def iplot(*args, show=True, **kwargs):
         >>> iplot(
         ...     (Polygon((a, b), c, n=d), ),
         ...     params = {
-        ...         a: (0, (-2, 2)),
-        ...         b: (0, (-2, 2)),
-        ...         c: (1, (0, 5)),
+        ...         a: (0, -2, 2),
+        ...         b: (0, -2, 2),
+        ...         c: (1, 0, 5),
         ...         d: param.Integer(3, softbounds=(3, 10), label="n"),
         ...     },
         ...     backend = MB,
@@ -591,3 +605,70 @@ def iplot(*args, show=True, **kwargs):
     if show:
         return i.show()
     return i
+
+
+def create_widgets(params, **kwargs):
+    """ Create panel's widgets starting from parameters.
+
+    Parameters
+    ==========
+
+    params : dict
+        A dictionary mapping the symbols to a parameter. The parameter can be:
+
+        1. an instance of ``param.parameterized.Parameter``. Refer to [#fn1]_
+           for a list of available parameters.
+        2. a tuple of the form:
+           ``(default, min, max, N [optional], label [optional], spacing [optional])``
+           where:
+
+           - N : int
+                Number of steps of the slider.
+           - min, max : float
+                End values of the range. Must be finite numbers.
+           - label: str
+                Custom text associated to the slider.
+           - spacing : str
+                Specify the discretization spacing. Default to ``"linear"``, can
+                be changed to ``"log"``.
+
+        Note that the parameters cannot be linked together (ie, one parameter
+        cannot depend on another one).
+
+    use_latex : bool, optional
+        Default to True.
+        If True, the latex representation of the symbols will be used in the
+        labels of the parameter-controls. If False, the string representation
+        will be used instead.
+
+
+    Returns
+    =======
+
+    widgets : dict
+        A dictionary mapping the symbols from ``params`` to the appropriate
+        widget.
+
+
+    Examples
+    ========
+
+    >>> from sympy.abc import x, y, z
+    >>> r = create_widgets({
+    ...     x: (2, 0, 4),
+    ...     y: (200, 1, 1000, 10, "test", "log"),
+    ...     z: param.Integer(3, softbounds=(3, 10), label="n")
+    ... })
+
+
+    References
+    ==========
+    .. [fn1] https://panel.holoviz.org/user_guide/Param.html
+    """
+    dp = DynamicParam(params=params, **kwargs)
+    tmp_panel = pn.Param(dp)
+
+    results = dict()
+    for k, v in dp.mapping.items():
+        results[k] = tmp_panel.widget(v)
+    return results
