@@ -398,73 +398,3 @@ def _split_vector(expr, ranges, fill_ranges=True):
         xexpr, yexpr, zexpr = expr
     split_expr = xexpr, yexpr, zexpr
     return split_expr, ranges
-
-
-def get_seeds_points(xx, yy, zz, uu, vv, ww):
-    """Returns an optimal list of seeds points to be used to generate 3D
-    streamlines.
-
-    Parameters
-    ==========
-        xx, yy, zz: np.ndarray
-            3D discretization of the space from meshgrid.
-
-        uu, vv, ww: np.ndarray
-            Vector components calculated at the discretized points in space.
-
-    Returns
-    =======
-        points : np.ndarray
-            [n x 3] matrix of seed-points coordinates.
-    """
-
-    # TODO: OPTIMIZE THIS CODE PLEASE!!!!!!!!!
-
-    coords = np.stack([xx, yy, zz])
-    # vector field
-    vf = np.stack([uu, vv, ww])
-
-    # extract the coordinate of the points at planes:
-    # x_min, x_max, y_min, y_max, z_min, z_max
-    c_xmin = coords[:, :, 0, :]
-    c_xmax = coords[:, :, -1, :]
-    c_ymin = coords[:, 0, :, :]
-    c_ymax = coords[:, -1, :, :]
-    c_zmin = coords[:, :, :, 0]
-    c_zmax = coords[:, :, :, -1]
-
-    # extract the vector field points at planes:
-    # x_min, x_max, y_min, y_max, z_min, z_max
-    vf_xmin = vf[:, :, 0, :]
-    vf_xmax = vf[:, :, -1, :]
-    vf_ymin = vf[:, 0, :, :]
-    vf_ymax = vf[:, -1, :, :]
-    vf_zmin = vf[:, :, :, 0]
-    vf_zmax = vf[:, :, :, -1]
-
-    def find_points_at_input_vectors(vf_plane, coords, i, sign="g"):
-        check = {
-            "g": lambda x: x > 0,
-            "l": lambda x: x < 0,
-        }
-        # extract coordinates where the vectors are entering the plane
-        tmp = np.where(
-            check[sign](vf_plane[i, :, :]), coords, np.nan * np.zeros_like(coords)
-        )
-        # reshape the matrix to obtain an [n x 3] array of coordinates
-        tmp = np.array(
-            [tmp[0, :, :].flatten(), tmp[1, :, :].flatten(), tmp[2, :, :].flatten()]
-        ).T
-        # remove NaN entries
-        tmp = [a for a in tmp if not np.all([np.isnan(t) for t in a])]
-        return tmp
-
-    p_xmin = find_points_at_input_vectors(vf_xmin, c_xmin, 0, "g")
-    p_xmax = find_points_at_input_vectors(vf_xmax, c_xmax, 0, "l")
-    p_ymin = find_points_at_input_vectors(vf_ymin, c_ymin, 1, "g")
-    p_ymax = find_points_at_input_vectors(vf_ymax, c_ymax, 1, "l")
-    p_zmin = find_points_at_input_vectors(vf_zmin, c_zmin, 2, "g")
-    p_zmax = find_points_at_input_vectors(vf_zmax, c_zmax, 2, "l")
-    # TODO: there could be duplicates
-    points = np.array(p_xmin + p_xmax + p_ymin + p_ymax + p_zmin + p_zmax)
-    return points
